@@ -8,10 +8,10 @@ ASGI Middleware Static File
 
 from .core import (  # noqa: F401
     ASGIMiddlewareStaticFile,
-    Path,
+    ASGIMiddlewarePath,
 )
 
-__version__ = '0.3.0'
+__version__ = '0.3.1'
 
 __author__ = 'Rex Zhang'
 __author_email__ = 'rex.zhang@gmail.com'
